<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/index14.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:40:44 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEOC - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo12.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage14-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader preloader14">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader12.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header>
    <div class="header-area homepage14 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo2.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu">
                      <div class="row">
                         <div class="col-lg-12">
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index1.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="404.html">SEO & Digital Marketing 01</a>
                                   </div>
                                 <div class="space20"></div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img2.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index2.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index2.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index2.html">SEO & Digital Marketing 02</a>
                                   </div>
                                 <div class="space20"></div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn22" href="index3.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn22" href="single-index3.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index3.html">SEO & Digital Marketing 03</a>
                               </div>
                               <div class="space20"></div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img3.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index4.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index4.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index4.html">SEO & Digital Marketing 04</a>
                                   </div>
                                 <div class="space20"></div>
                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img4.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index5.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index5.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                              </div>
                              <div class="homemenu-content">
                                <a href="index5.html">SEO & Digital Marketing 05</a>
                               </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img11.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index11.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index11.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index11.html">Staffing Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img12.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index12.html" target="_blank"> Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index12.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index12.html">Consulting Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn22" href="index13.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn22" href="single-index13.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index13.html">Advertising Agency</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img14.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index14.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index14.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index14.html">IT Solution Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img15.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index15.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index15.html" target="_blank"> One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index15.html">Startup Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img5.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index6.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index6.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index6.html">SEO & Digital Marketing 06</a>
                                   </div>

                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img6.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index7.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index7.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index7.html">SEO & Digital Marketing 07</a>
                                   </div>

                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img7.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn22" href="index8.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn22" href="single-index8.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>

                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img8.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index9.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index9.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index9.html">SEO & Digital Marketing 09</a>
                                   </div>

                              </div>
                            </div>
                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img9.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>HOT</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn22" href="index10.html" target="_blank">Multi Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn22" href="single-index10.html" target="_blank">One Page <span><i class="fa-solid fa-angle-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                    <a href="index10.html">SEO & Digital Marketing 10</a>
                                   </div>

                              </div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img17.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">Creative Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img16.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">Digital Marketing Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                                </div>
                               <div class="homemenu-content">
                                <a href="index8.html">Digital Marketer Agency</a>
                               </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img19.png" alt="">
                                </div>
  
                                 <div class="homemenu-content">
                                  <a href="index9.html">Corporate Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img20.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">Coming Soon</a>
                                 </div>
                              </div>
                            </div>
                          </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>

              <div class="btn-area">
                <a href="contact.html" class="header-btn23">Get Free Quote <i class="fa-solid fa-angle-right"></i></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder14 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo2.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar14">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo2.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
  <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="404-5.html">Service One</a></li>
          <li><a href="404-6.html">Service Left</a></li>
          <li><a href="404-7.html">Service Right</a></li>
          <li><a href="404-8.html">Service Single</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="404-9.html">Case Study Left</a></li>
          <li><a href="404-10.html">Case Study Right</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn22">Get Started</a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="hero14-section-area">
    <img src="assets/img/elements/elements27.png" alt="" class="elements27 aniamtion-key-2">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-5">
                <div class="hero-header14 heading21">
                    <h5 data-aos="fade-left" data-aos-duration="800">Top #1 IT Solution Agency</h5>
                    <h1 class="text-anime-style-3">Next-Generation IT Solutions for Every  And Business</h1>
                    <p data-aos="fade-left" data-aos-duration="1000">We specialize delivering innovative, tailored IT solutions that empower businesses to thrive in today’s digital landscape. </p>
                    <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
                        <div class="space30"></div>
                        <a href="contact.html" class="header-btn23">Our Success Stories <i class="fa-solid fa-angle-right"></i></a>
                        <a href="contact.html" class="header-btn23 btn2">Contact Us <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
            <div class="col-lg-1"></div>
            <div class="col-lg-6">
                <div class="header-images-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/header-img14.png" alt="" class="header-img">
                        <img src="assets/img/elements/elements28.png" alt="" class="elements28 aniamtion-key-2">
                        <img src="assets/img/elements/elements29.png" alt="" class="keyframe5 elements29">
                        <div class="others-box aniamtion-key-1">
                            <div class="icons">
                                <img src="assets/img/icons/check15.svg" alt="">
                            </div>
                            <p>With 12+ years of experience
                                helping the community.</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->

<!--===== ABOUT AREA STARTS =======-->
<div class="about14-section-area sp1">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-6">
                <div class="about14-images-area">
                    <div class="img1 image-anime reveal">
                        <img src="assets/img/all-images/new-img/about-img1-h14.png" alt="">
                    </div>
                    <div class="img2 reveal">
                        <img src="assets/img/all-images/new-img/about-img2-h14.png" alt="">
                    </div>
                    <img src="assets/img/elements/elements30.png" alt="" class="elements30">
                    <img src="assets/img/elements/elements31.png" alt="" class="elements31">
                </div>
            </div>
            <div class="col-lg-6">
                <div class="about-header-area heading22">
                    <h5>About Us </h5>
                    <h2 class="text-anime-style-3">Empowering Businesses with Cutting IT Solutions</h2>
                    <p data-aos="fade-left" data-aos-duration="1000">We are passionate about the power of technology to drive meaningful change for businesses. With a team of dedicated IT experts, we provide tailored solutions designed  the unique challenges of every client.</p>
                    <div class="space32"></div>
                    <h3 data-aos="fade-left" data-aos-duration="1100">Our Best Service Benefits :</h3>
                    <div class="space8"></div>
                    <div class="list-area" data-aos="fade-left" data-aos-duration="1200">
                        <ul>
                            <li><img src="assets/img/icons/check15.svg" alt="">Businesses Through Technology Expertise</li>
                            <li><img src="assets/img/icons/check15.svg" alt="">Innovating the Future of Technology</li>
                            <li><img src="assets/img/icons/check15.svg" alt="">Building Smarter Solutions, Together</li>
                        </ul>
                    </div>
                    <div class="images-area" data-aos="fade-left" data-aos-duration="1400">
                        <div class="img">
                            <img src="assets/img/all-images/about-img4.png" alt="">
                        </div>
                        <div class="content-area">
                            <a href="team.html">James Anderson</a>
                            <p>Agency Owner</p>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== ABOUT AREA ENDS =======-->

<!--===== SERVICE AREA STARTS =======-->
<div class="service14-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="service14-header text-center heading22 space-margin60">
                    <h5>Our Service</h5>
                    <h2 class="text-anime-style-3">Strategic IT Services for the Future-Ready Business</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="700">
                <div class="service14-widget-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/service-img1-h14.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons33.svg" alt="">
                        </div>
                        <a href="service1.html">Cloud Solutions & Infrastructure</a>
                    </div>
                    <div class="content-widget-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons33.svg" alt="">
                        </div>
                        <div class="space32"></div>
                        <a href="service1.html">Cloud Solutions & Infrastructure</a>
                        <div class="space16"></div>
                        <p>We are committed to delivering reliable, scalable, and cutting-edge IT services that empower your business to thrive in today.</p>
                        <div class="space24"></div>
                        <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
    
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="service14-widget-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/service-img2-h14.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons34.svg" alt="">
                        </div>
                        <a href="service1.html">IT Support & Helpdesk Services</a>
                    </div>
                    <div class="content-widget-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons34.svg" alt="">
                        </div>
                        <div class="space32"></div>
                        <a href="service1.html">IT Support & Helpdesk Services</a>
                        <div class="space16"></div>
                        <p>We are committed to delivering reliable, scalable, and cutting-edge IT services that empower your business to thrive in today.</p>
                        <div class="space24"></div>
                        <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
            
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="900">
                <div class="service14-widget-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/service-img3-h14.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons35.svg" alt="">
                        </div>
                        <a href="service1.html">Custom Software Development</a>
                    </div>
                    <div class="content-widget-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons35.svg" alt="">
                        </div>
                        <div class="space32"></div>
                        <a href="service1.html">Custom Software Development</a>
                        <div class="space16"></div>
                        <p>We are committed to delivering reliable, scalable, and cutting-edge IT services that empower your business to thrive in today.</p>
                        <div class="space24"></div>
                        <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
            
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="service14-widget-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/service-img4-h14.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons36.svg" alt="">
                        </div>
                        <a href="service1.html">Digital Transformation Services</a>
                    </div>
                    <div class="content-widget-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons36.svg" alt="">
                        </div>
                        <div class="space32"></div>
                        <a href="service1.html">Digital Transformation Services</a>
                        <div class="space16"></div>
                        <p>We are committed to delivering reliable, scalable, and cutting-edge IT services that empower your business to thrive in today.</p>
                        <div class="space24"></div>
                        <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
                <div class="service14-widget-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/service-img5-h14.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons37.svg" alt="">
                        </div>
                        <a href="service1.html">IT Infrastructure Monitoring</a>
                    </div>
                    <div class="content-widget-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons37.svg" alt="">
                        </div>
                        <div class="space32"></div>
                        <a href="service1.html">IT Infrastructure Monitoring</a>
                        <div class="space16"></div>
                        <p>We are committed to delivering reliable, scalable, and cutting-edge IT services that empower your business to thrive in today.</p>
                        <div class="space24"></div>
                        <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="service14-widget-area">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/service-img1-h14.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons38.svg" alt="">
                        </div>
                        <a href="service1.html">Cloud Migration & Optimization</a>
                    </div>
                    <div class="content-widget-area">
                        <div class="icons">
                            <img src="assets/img/icons/service-icons38.svg" alt="">
                        </div>
                        <div class="space32"></div>
                        <a href="service1.html">Cloud Migration & Optimization</a>
                        <div class="space16"></div>
                        <p>We are committed to delivering reliable, scalable, and cutting-edge IT services that empower your business to thrive in today.</p>
                        <div class="space24"></div>
                        <a href="service1.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== SERVICE AREA ENDS =======-->

<!--===== CASE AREA STARTS =======-->
<div class="case14-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-6">
                <div class="case14-header heading22 space-margin60">
                    <h5>Case Studies</h5>
                    <h2 class="text-anime-style-3">Proven Solutions: How We’ve Helped Businesses Thrive</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12">
                <div class="case14-slider-area owl-carousel">
                    <div class="case14-boxarea">
                        <div class="img1 image-anime">
                            <img src="assets/img/all-images/new-img/case-img1-h14.png" alt="">
                        </div>
                        <div class="content-area">
                            <p>#IT Solution Agency</p>
                            <div class="space12"></div>
                            <a href="case-single.html">Digital Transformation for <br class="d-lg-block d-none"> Operational Efficiency</a>
                            <div class="arrow">
                                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>

                    <div class="case14-boxarea">
                        <div class="img1 image-anime">
                            <img src="assets/img/all-images/new-img/case-img2-h14.png" alt="">
                        </div>
                        <div class="content-area">
                            <p>#IT Solution Agency Success</p>
                            <div class="space12"></div>
                            <a href="case-single.html">Custom Software Development <br class="d-lg-block d-none"> for Business Growth</a>
                            <div class="arrow">
                                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>

                    <div class="case14-boxarea">
                        <div class="img1 image-anime">
                            <img src="assets/img/all-images/new-img/case-img3-h14.png" alt="">
                        </div>
                        <div class="content-area">
                            <p>#IT Solution Agency Challenge</p>
                            <div class="space12"></div>
                            <a href="case-single.html">IT Infrastructure Modernization <br class="d-lg-block d-none"> for Future Readiness</a>
                            <div class="arrow">
                                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>
                    <div class="case14-boxarea">
                        <div class="img1 image-anime">
                            <img src="assets/img/all-images/new-img/case-img1-h14.png" alt="">
                        </div>
                        <div class="content-area">
                            <p>#IT Solution Agency</p>
                            <div class="space12"></div>
                            <a href="case-single.html">Digital Transformation for <br class="d-lg-block d-none"> Operational Efficiency</a>
                            <div class="arrow">
                                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>

                    <div class="case14-boxarea">
                        <div class="img1 image-anime">
                            <img src="assets/img/all-images/new-img/case-img2-h14.png" alt="">
                        </div>
                        <div class="content-area">
                            <p>#IT Solution Agency Success</p>
                            <div class="space12"></div>
                            <a href="case-single.html">Custom Software Development <br class="d-lg-block d-none"> for Business Growth</a>
                            <div class="arrow">
                                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>

                    <div class="case14-boxarea">
                        <div class="img1 image-anime">
                            <img src="assets/img/all-images/new-img/case-img3-h14.png" alt="">
                        </div>
                        <div class="content-area">
                            <p>#IT Solution Agency Challenge</p>
                            <div class="space12"></div>
                            <a href="case-single.html">IT Infrastructure Modernization <br class="d-lg-block d-none"> for Future Readiness</a>
                            <div class="arrow">
                                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== CASE AREA ENDS =======-->

<!--===== TESTIMONIAL AREA STARTS =======-->
<div class="testimonial14-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-5 m-auto">
                <div class="testimonial14-header text-center heading22 space-margin60">
                    <h5>Testimonial</h5>
                    <h2>Partnering for Success: Client Experiences</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-12">
                <div class="testimonial14-slider-area owl-carousel">
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img1-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                    <div class="testimonial14-boxarea">
                        <div class="list-area">
                            <ul>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                                <li><i class="fa-solid fa-star"></i></li>
                            </ul>
                            <img src="assets/img/icons/quito9.svg" alt="">
                        </div>
                        <div class="space14"></div>
                        <p>“Partnering with Scoc has been one of the best decisions for our business their team not only provided expert IT solutions but also became a trusted advisor our long.”</p>
                        <div class="space16"></div>
                        <div class="name-area">
                            <div class="name">
                                <img src="assets/img/all-images/new-img/testimonial-img2-h13.png" alt="">
                            
                            <div class="text">
                                <a href="#">Marta Connelly</a>
                                <p>Company Owner</p>
                            </div>
                        </div>
                        <img src="assets/img/icons/google.svg" alt="" class="google">
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== TESTIMONIAL AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team14-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="team14-header space-margin60 heading22 text-center">
                    <h5>Our Team</h5>
                    <h2 class="text-anime-style-3">The People Powering Your <br class="d-lg-block d-none"> IT Solutions</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="our-team-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/team-img1-h14.png" alt="">
                    </div>
                    <div class="content">
                        <a href="team.html">Salvador Cassin</a>
                        <div class="space12"></div>
                        <p>Business Analytics</p>
                    </div>
                    <div class="share">
                        <a href="#"><img src="assets/img/icons/share1.svg" alt=""></a>
                    </div>
                    <ul>
                        <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="our-team-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/team-img2-h14.png" alt="">
                    </div>
                    <div class="content">
                        <a href="team.html">Mrs. Nellie Windler</a>
                        <div class="space12"></div>
                        <p>Business Analytics</p>
                    </div>
                    <div class="share">
                        <a href="#"><img src="assets/img/icons/share1.svg" alt=""></a>
                    </div>
                    <ul>
                        <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="our-team-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/team-img3-h14.png" alt="">
                    </div>
                    <div class="content">
                        <a href="team.html">Johnnie MacGyver</a>
                        <div class="space12"></div>
                        <p>Business Analytics</p>
                    </div>
                    <div class="share">
                        <a href="#"><img src="assets/img/icons/share1.svg" alt=""></a>
                    </div>
                    <ul>
                        <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                        <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== TEAM AREA ENDS =======-->

<!--===== CONTACT AREA STARTS =======-->
<div class="contact14-section-area">
    <div class="mapouter">
        <div class="gmap_canvas">
          <iframe src="https://www.google.com/maps/embed?pb=!1m14!1m12!1m3!1d4506257.120552435!2d88.67021924228865!3d21.954385721237916!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!5e0!3m2!1sen!2sbd!4v1704088968016!5m2!1sen!2sbd" width="600" height="450" style="border:0;" allowfullscreen="" loading="lazy" referrerpolicy="no-referrer-when-downgrade"></iframe>
        </div>
      </div> 
    <div class="container">
        <div class="row">
            <div class="col-lg-12">
                <div class="contact-author-boxarea">
                    <div class="row align-items-center">
                        <div class="col-lg-7">
                            <div class="contact-input-area">
                                <h4>Send Us A Message</h4>
                                <div class="space16"></div>
                                <p>Our response time is within 30 minutes during business hours</p>
                                <div class="space8"></div>
                                <div class="row">
                                    <div class="col-lg-6">
                                        <div class="input-area">
                                            <input type="text" placeholder="First Name">
                                        </div>
                                    </div>
                                    <div class="col-lg-6">
                                        <div class="input-area">
                                            <input type="text" placeholder="Last Name">
                                        </div>
                                    </div>
                                    <div class="col-lg-6">
                                        <div class="input-area">
                                            <input type="number" placeholder="Phone Number">
                                        </div>
                                    </div>
                                    <div class="col-lg-6">
                                        <div class="input-area">
                                            <input type="email" placeholder="Email Address">
                                        </div>
                                    </div>
                                    <div class="col-lg-12">
                                        <div class="input-area">
                                            <select name="country" id="country" class="country-area nice-select6">
                                                <option value="1" data-display="Service Type">Service Type</option>
                                                <option value="">Option 01</option>
                                                <option value="">Option 02</option>
                                                <option value="">Option 03</option>
                                                <option value="">Option 04</option>
                                                <option value="">Option 05</option>
                                              </select>
                                        </div>
                                    </div>
                                    <div class="col-lg-12">
                                        <div class="input-area">
                                            <textarea name="#" id="#" placeholder="Message"></textarea>
                                        </div>
                                    </div>
                                    <div class="col-lg-12">
                                        <div class="space12"></div>
                                        <div class="input-area text-end">
                                            <button type="submit" class="header-btn23">Submit Now <i class="fa-solid fa-angle-right"></i></button>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>

                        <div class="col-lg-5">
                            <div class="contact-boxarea">
                                <div class="icons">
                                    <img src="assets/img/icons/location9.svg" alt="">
                                </div>
                                <div class="text">
                                    <h4>Our Location</h4>
                                    <div class="space16"></div>
                                    <a href="#">8708 Technology Forest Pl Suite <br class="d-lg-block d-none"> 125 -G, The Woodlands, TX 77381</a>
                                </div>
                            </div>
                            <div class="space20"></div>
                            <div class="contact-boxarea">
                                <div class="icons">
                                    <img src="assets/img/icons/phone6.svg" alt="">
                                </div>
                                <div class="text">
                                    <h4>Call Or Text</h4>
                                    <div class="space16"></div>
                                    <a href="tel:123-456-7890">123-456-7890</a>
                                </div>
                            </div>
                            <div class="space20"></div>
                            <div class="contact-boxarea">
                                <div class="icons">
                                    <img src="assets/img/icons/emai6.svg" alt="">
                                </div>
                                <div class="text">
                                    <h4>Email us today</h4>
                                    <div class="space16"></div>
                                    <a href="mailto:info@taxvice.com">info@taxvice.com</a>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== CONTACT AREA ENDS =======-->

<!--===== BLOG AREA STARTS =======-->
<div class="blog14-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-5 m-auto">
                <div class="blog14-header text-center heading22 space-margin60">
                    <h5>Our Blog</h5>
                    <h2 class="text-anime-style-3">Your IT Resource Hub: News, Tips, and Trends</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="blog14-widget-area">
                    <div class="content-area">
                        <ul>
                            <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 12 Nov 2024</a> </li>
                            <li class="m-0"><a href="#"><i class="fa-regular fa-user"></i> John Doe</a> </li>
                        </ul>
                        <div class="space20"></div>
                        <a href="blog-single.html">Navigating IT Challenges: Solutions <br class="d-lg-block d-none"> and Strategies for Success</a>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                    <div class="space24"></div>
                    <div class="img1 image-anime">
                        <img src="assets/img/all-images/new-img/blog-img1-h14.png" alt="">
                    </div>
                </div>
            </div>
    
            <div class="col-lg-6">
                <div class="blog14-widget-area" data-aos="zoom-in" data-aos-duration="1100">
                    <div class="row align-items-center">
                        <div class="col-lg-5 col-md-6" >
                            <div class="img2 image-anime">
                                <img src="assets/img/all-images/new-img/blog-img2-h14.png" alt="">
                            </div>
                        </div>
                        <div class="col-lg-7 col-md-6">
                            <div class="content-area">
                                <ul>
                                    <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 12 Nov 2024</a> </li>
                                    <li class="m-0"><a href="#"><i class="fa-regular fa-user"></i> John Doe</a> </li>
                                </ul>
                                <div class="space20"></div>
                                <a href="blog-single.html">Expert Advice on Emerging Technologies and Best Practices </a>
                                <div class="space24"></div>
                                <a href="blog-single.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                            </div>
                        </div>
                    </div>                
                </div>
                <div class="blog14-widget-area" data-aos="zoom-in" data-aos-duration="1200">
                    <div class="row align-items-center">
                        <div class="col-lg-5 col-md-6">
                            <div class="img2 image-anime">
                                <img src="assets/img/all-images/new-img/blog-img3-h14.png" alt="">
                            </div>
                        </div>
                        <div class="col-lg-7 col-md-6">
                            <div class="content-area">
                                <ul>
                                    <li><a href="#"><i class="fa-regular fa-calendar-days"></i> 12 Nov 2024</a> </li>
                                    <li class="m-0"><a href="#"><i class="fa-regular fa-user"></i> John Doe</a> </li>
                                </ul>
                                <div class="space20"></div>
                                <a href="blog-single.html">Unlocking the Latest IT Trends: Insights and Innovations</a>
                                <div class="space24"></div>
                                <a href="blog-single.html" class="readmore">Learn More <i class="fa-solid fa-angle-right"></i></a>
                            </div>
                        </div>
                    </div>                
                </div>
            </div>

        </div>
    </div>
</div>
<!--===== BLOG AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta14-section-area sp1">
    <img src="assets/img/elements/elements27.png" alt="" class="elements27 aniamtion-key-2">
    <div class="container">
        <div class="row">
            <div class="col-lg-5">
                <div class="cta14-header heading21">
                    <h2 class="text-anime-style-3">Get Started with Expert IT Solutions Today</h2>
                    <p data-aos="fade-left" data-aos-duration="800">Ready to take your business to the next level with innovative IT solutions? Our team of experts is here to help you unlock.</p>
                    <div class="btn-area1">
                        <div class="space32"></div>
                        <a href="contact.html" class="header-btn23">Get a Custom Quote <i class="fa-solid fa-angle-right"></i></a>
                        <a href="contact.html" class="header-btn23 btn2">Get Started <i class="fa-solid fa-angle-right"></i></a>
                    </div>
                </div>
            </div>
            <div class="col-lg-3">
                <div class="rating-box">
                    <p>5 Star Review</p>
                    <div class="space12"></div>
                    <ul>
                        <li><i class="fa-solid fa-star"></i></li>
                        <li><i class="fa-solid fa-star"></i></li>
                        <li><i class="fa-solid fa-star"></i></li>
                        <li><i class="fa-solid fa-star"></i></li>
                        <li><i class="fa-solid fa-star"></i></li>
                    </ul>
                </div>
            </div>
            <div class="col-lg-4">
                <div class="cta-images">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/cta-img1-h14.png" alt="" class="cta-img1-h14">
                    </div>
                    <img src="assets/img/elements/elements29.png" alt="" class="elements29 keyframe5">
                </div>
            </div>
        </div>
    </div>
</div>
  <!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer14-section-area">
    <div class="container">
      <div class="row">
        <div class="col-lg-3 col-md-6">
          <div class="footer-logo-area">
            <img src="assets/img/logo/logo15.png" alt="">
            <p>By optimizing content, leveraging relevant keywords, and adhering to best practices, businesses can secure prominent position (SEO)</p>
            <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
            </ul>
          </div>
        </div>
  
        <div class="col-lg-2 col-md-6">
          <div class="footer-logo-area1">
            <h3>About Link</h3>
            <ul>
              <li><a href="blog.html">Our Blog</a></li>
            <li><a href="about.html">About Us</a></li>
            <li><a href="service1.html">Services</a></li>
            <li><a href="case.html">Marketing</a></li>
            <li><a href="testimonials.html">Testimonials</a></li>
            <li><a href="contact.html">Contact Us</a></li>
            </ul>
          </div>
        </div>
  
        <div class="col-lg-3 col-md-6">
          <div class="footer-logo-area2">
            <h3>Get in touch</h3>
            <ul>
              <li><a href="404-4.html"><img src="assets/img/icons/email.svg" alt=""><span>Infoseoc@gmail.com</span></a></li>
              <li><a href="#"><img src="assets/img/icons/location.svg" alt=""><span>8708 Technology Forest <br class="d-lg-block d-none"> Pl Suite 125 -G, The <br class="d-lg-block d-none"> Woodlands, TX 773</span></a></li>
              <li><a href="tel:123-456-7890"><img src="assets/img/icons/phone.svg" alt=""><span>123-456-7890</span></a></li>
            </ul>
          </div>
        </div>
        <div class="col-lg-4 col-md-6">
          <div class="footer-logo-area3">
            <h3>Subscribe Our Newsletter</h3>
            <form action="#">
              <input type="text" placeholder="Enter Your email">
              <button class="header-btn22"> Subscribe <i class="fa-solid fa-angle-right"></i></button>
            </form>
          </div>
        </div>
      </div>
      <div class="space80 d-lg-block d-none"></div>
      <div class="space40 d-lg-none d-block"></div>
      <div class="row">
        <div class="col-lg-12">
          <div class="copyright-area">
            <div class="pera">
              <p>ⓒCopyright 2024 SEOC . All rights reserved</p>
            </div>
            <ul>
              <li><a href="#">Terms & Conditions</a></li>
              <li><a href="#" class="m-0"> Privacy Policy </a></li>
            </ul>
          </div>
        </div>
      </div>
    </div>
  </div>
<!--===== FOOTER AREA ENDS =======-->


<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/index14.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:41:01 GMT -->
</html>